#Sys.setenv(R_REMOTES_NO_ERRORS_FROM_WARNINGS="true")
#devtools::install_git(url = "https://github.com/kkleinke/countimp", 
#                      ref = "master")


##################### 
##                 ##
## asthma analysis ##
##                 ##
#####################

data <- analysisData20210513 <- readRDS("analysisData20210513.rds")

## subset
data1 = data[, c("baby_studyid", "estWtChangePerWk", "est_bmi_preg_mother", "mat_age_delivery", "male", "child_birth_weight.ph1",  "mat4race", "hispanic", "mat_diabetes3", 
                 "cesarean", "depressionr", "tobacPregr", "insurancer", "singleton", "married", "number_children", "egaWk", "mat_asthma", "asthma",
                 "estWtChangePerWk.ph1", "est_bmi_preg_mother.ph1", "mat_age_delivery.ph1", "mat4race.ph1", "hispanic.ph1", "mat_diabetes3.ph1",
                 "cesarean.ph1", "male.ph1", "depressionr.ph1", "tobacPregr.ph1", "insurancer.ph1", "mat_asthma.ph1", "singleton.ph1", "asthma.ph1", "in.Aframe",
                 "in.Oframe", "in.phase2")]

data1$mat4race = as.factor(data1$mat4race)
data1$mat_diabetes3 = as.factor(data1$mat_diabetes3)
data1$hispanic = as.factor(data1$hispanic)
data1$cesarean = as.factor(data1$cesarean)
data1$male = as.factor(data1$male)
data1$depressionr = as.factor(data1$depressionr)
data1$tobacPregr = as.factor(data1$tobacPregr)
data1$insurancer = as.factor(data1$insurancer)
data1$singleton = as.factor(data1$singleton)
data1$married = as.factor(data1$married)
data1$mat_asthma = as.factor(data1$mat_asthma)
data1$asthma = as.factor(data1$asthma)
data1$mat4race.ph1 = as.factor(data1$mat4race.ph1)
data1$hispanic.ph1 = as.factor(data1$hispanic.ph1)
data1$mat_diabetes3.ph1 = as.factor(data1$mat_diabetes3.ph1)
data1$cesarean.ph1 = as.factor(data1$cesarean.ph1)
data1$male.ph1 = as.factor(data1$male.ph1)
data1$depressionr.ph1 = as.factor(data1$depressionr.ph1)
data1$tobacPregr.ph1 = as.factor(data1$tobacPregr.ph1)
data1$insurancer.ph1 = as.factor(data1$insurancer.ph1)
data1$mat_asthma.ph1 = as.factor(data1$mat_asthma.ph1)
data1$singleton.ph1 = as.factor(data1$singleton.ph1)
data1$asthma.ph1 = as.factor(data1$asthma.ph1)





## asthma imputation
bothPhases = data1[data1$in.Aframe == 1, 1:36]
bothPhases1 = bothPhases[bothPhases$in.phase2 == 1, ]
bothPhases1[, 6:17] = NA
bothPhases2 = rbind(bothPhases, bothPhases1)


library(mice)
library(countimp)


ini <- mice(bothPhases2, maxit = 0)
ini$predictorMatrix = matrix(0, nrow = nrow(ini$predictorMatrix), ncol = ncol(ini$predictorMatrix),
                             dimnames = list(row.names(ini$predictorMatrix), row.names(ini$predictorMatrix)))

## specify the imputation model
colSums(!apply(bothPhases2, 2, is.na))
#ini$predictorMatrix["mat_age_delivery", 19:32] = 1
#ini$predictorMatrix["male", c(5:8, 19:32)] = 1

ini$predictorMatrix["child_birth_weight.ph1", 20:32] = 1
ini$predictorMatrix["mat4race", c(6, 20:32)] = 1
ini$predictorMatrix["hispanic", c(6:7, 20:32)] = 1
ini$predictorMatrix["mat_diabetes3", c(6:8, 20:32)] = 1
ini$predictorMatrix["cesarean", c(6:9, 20:32)] = 1
ini$predictorMatrix["depressionr", c(6:10, 20:32)] = 1
ini$predictorMatrix["tobacPregr", c(6:11, 20:32)] = 1
ini$predictorMatrix["insurancer", c(6:12, 20:32)] = 1
ini$predictorMatrix["singleton", c(6:13, 20:32)] = 1
ini$predictorMatrix["married", c(6:14, 20:32)] = 1
ini$predictorMatrix["number_children", c(6:15, 20:32)] = 1
ini$predictorMatrix["egaWk", c(6:16, 20:32)] = 1

meth = ini$method
meth[meth!=""] = ""
meth["child_birth_weight.ph1"] = "norm"
meth["mat4race"] = "polyreg"
meth["hispanic"] = "logreg"
meth["mat_diabetes3"] = "polyreg"
meth["cesarean"] = "logreg"
meth["depressionr"] = "logreg"
meth["tobacPregr"] = "logreg"
meth["insurancer"] = "logreg"
meth["singleton"] = "logreg"
meth["married"] = "logreg"
meth[c("number_children")] = "qpois"
meth[c("egaWk")] = "norm"


post <- ini$post
post["egaWk"] <- "imp[[j]][,i] <- squeeze(imp[[j]][,i],c(24,44))"

mip = matrix(FALSE, nrow = nrow(bothPhases2), ncol = ncol(bothPhases2))
mip[,c(6:15, 17)] = TRUE
mip[, 16] = is.na(bothPhases2$number_children)

imp = mice(bothPhases2, meth = meth, pred = ini$predictorMatrix, print = F, m = 100, post = post,
           where = mip, seed = 0111)


id = impdata_w2[[1]]
id = id[, c(1, 17)]

imp.data = list()
for(i in 1:100){
  ff = complete(imp, i)[1:7053,]
  ff1 = complete(imp, i)[7054:7881,]
  ff[ff$in.phase2 == 1,]$number_children = ff1$number_children
  imp.data[[i]] = ff
}

imp.data.id = list()
for(i in 1:100){
  imp.data.id[[i]] = merge(imp.data[[i]], id, by="baby_studyid")
}



saveRDS(imp.data.id, file = "impdata_asthma.rds")
saveRDS(id, file = "id.rds")



out.list = list()
for (i in 1:100){
  out.list[[i]] = readRDS(paste0("out", i, ".rds"))
  out.list[[i]]$est_bmi_gest_imp = out.list[[i]]$est_bmi_gest
  out.list[[i]]$estWtChangePerWk_imp = out.list[[i]]$estWtChangePerWk
  out.list[[i]]$est_bmi_gest = NULL
  out.list[[i]]$estWtChangePerWk = NULL
}


imp.data.w2 = readRDS("impdata_w2.rds")
combine.list = list()
for(i in 1:100){
  combine.list[[i]] = merge(imp.data.id[[i]], out.list[[i]], by="baby_studyid")
}

saveRDS(combine.list, "combine_data_asthma.rds")



#####################################################
##                                                 ##
##  Step 3: impute asthma.mother and asthma.child  ##
##                                                 ##
#####################################################

combine.list = readRDS("combine_data_asthma.rds")

for(i in 1:100){
  set.seed(1024 * i)
  impute1 = glm(mat_asthma ~ mat_asthma.ph1 + estWtChangePerWk_imp + estWtChangePerWk.ph1 + est_bmi_gest_imp + est_bmi_preg_mother.ph1 + egaWk + 
                  mat_age_delivery.ph1 + mat4race + hispanic + hispanic.ph1 +
                  mat_diabetes3 + mat_diabetes3.ph1 + cesarean + male.ph1 + tobacPregr + tobacPregr.ph1 + insurancer + insurancer.ph1 + 
                  number_children + depressionr + married,
                family=binomial,
                data=combine.list[[i]])
  combine.list[[i]]$mat_asthma.imp <- rbinom(nrow(combine.list[[i]]), 1, 
                                                as.vector(predict(impute1, newdata=combine.list[[i]],
                                                                  type="response", se.fit=FALSE)))
  impute2 = glm(asthma ~ mat_asthma.ph1 + asthma.ph1 + mat_asthma.imp + estWtChangePerWk_imp + estWtChangePerWk.ph1 + est_bmi_gest_imp + est_bmi_preg_mother.ph1 + 
                  egaWk + mat_age_delivery.ph1 + mat4race + hispanic.ph1 +
                  hispanic + mat_diabetes3 + mat_diabetes3.ph1 + cesarean + male.ph1 + tobacPregr + tobacPregr.ph1 + insurancer + insurancer.ph1 +
                  number_children + depressionr + married,
                family=binomial,
                data=combine.list[[i]])
  combine.list[[i]]$asthma.imp <- rbinom(nrow(combine.list[[i]]), 1, 
                                               as.vector(predict(impute2, newdata=combine.list[[i]],
                                                                 type="response", se.fit=FALSE)))
}


####################################################################
##                                                                ##   
##  Step 4:fit the outcome model and compute influence functions  ##
##                                                                ##                        
####################################################################
inf.fun <- function(fit) {
  dm <- model.matrix(fit)
  Ihat <- (t(dm) %*% (dm * fit$fitted.values * (1 - fit$fitted.values))) / nrow(dm)
  ## influence function
  infl <- (dm * resid(fit, type = "response")) %*% solve(Ihat)
  infl
}

inffun_mi <- matrix(0, nrow = nrow(combine.list[[1]]), ncol = 16)
for (i in 1:100){
  mod = glm(asthma.imp~estWtChangePerWk_imp+ est_bmi_gest_imp +mat_age_delivery.ph1+ relevel(as.factor(mat4race),ref="White")+ hispanic+ 
              relevel(as.factor(mat_diabetes3),ref="None")+mat_asthma.imp+cesarean + male.ph1+ tobacPregr+ insurancer+egaWk, family="binomial",
            data = combine.list[[i]])
  inffun_mi<-inffun_mi + inf.fun(mod) 
}

inffun_mi<-inffun_mi/100

inffun_mi = cbind(inffun_mi, combine.list[[1]]$baby_studyid, as.numeric(combine.list[[1]]$mom_studyid))
colnames(inffun_mi)[c(17,18)] = c("baby_studyid", "mom_studyid")


saveRDS(inffun_mi, file = "inffun_asthma.rds")






