#Sys.setenv(R_REMOTES_NO_ERRORS_FROM_WARNINGS="true")
#devtools::install_git(url = "https://github.com/kkleinke/countimp", 
#                      ref = "master")


###################### 
##                  ##
## Obesity analysis ##
##                  ##
######################

data <- analysisData20210513 <- readRDS("analysisData20210513.rds")

## subset
data1 = data[, c("baby_studyid", "estWtChangePerWk", "est_bmi_preg_mother", "mat_age_delivery", "male", "ttobesity", "obesity", 
                 "ttobesity.ph1", "child_birth_weight.ph1",  "mat4race", "hispanic", "mat_diabetes3", 
                 "cesarean", "depressionr", "tobacPregr", "insurancer", "singleton", "married", "number_children", "egaWk",
                 "estWtChangePerWk.ph1", "est_bmi_preg_mother.ph1", "mat_age_delivery.ph1", "mat4race.ph1", "hispanic.ph1", "mat_diabetes3.ph1",
                 "cesarean.ph1", "male.ph1", "depressionr.ph1", "tobacPregr.ph1", "insurancer.ph1", "singleton.ph1", "obesity.ph1",
                 "in.Oframe", "in.phase2")]



colSums(!apply(data1, 2, is.na))




data1$mat4race = as.factor(data1$mat4race)
data1$mat_diabetes3 = as.factor(data1$mat_diabetes3)
data1$hispanic = as.factor(data1$hispanic)
data1$cesarean = as.factor(data1$cesarean)
data1$male = as.factor(data1$male)
data1$depressionr = as.factor(data1$depressionr)
data1$tobacPregr = as.factor(data1$tobacPregr)
data1$insurancer = as.factor(data1$insurancer)
data1$singleton = as.factor(data1$singleton)
data1$married = as.factor(data1$married)
data1$obesity = as.factor(data1$obesity)
data1$obesity.ph1 = as.factor(data1$obesity.ph1)
data1$mat4race.ph1 = as.factor(data1$mat4race.ph1)
data1$hispanic.ph1 = as.factor(data1$hispanic.ph1)
data1$mat_diabetes3.ph1 = as.factor(data1$mat_diabetes3.ph1)
data1$cesarean.ph1 = as.factor(data1$cesarean.ph1)
data1$male.ph1 = as.factor(data1$male.ph1)
data1$depressionr.ph1 = as.factor(data1$depressionr.ph1)
data1$tobacPregr.ph1 = as.factor(data1$tobacPregr.ph1)
data1$insurancer.ph1 = as.factor(data1$insurancer.ph1)
data1$singleton.ph1 = as.factor(data1$singleton.ph1)





## obesity imputation
bothPhases = data1
bothPhases1 = bothPhases[bothPhases$in.phase2 == 1, ]
bothPhases1[, 9:20] = NA
bothPhases2 = rbind(bothPhases, bothPhases1)
nrow(bothPhases2)# 11311 rows

library(mice)
library(countimp)


ini <- mice(bothPhases2, maxit = 0)
ini$predictorMatrix = matrix(0, nrow = nrow(ini$predictorMatrix), ncol = ncol(ini$predictorMatrix),
                             dimnames = list(row.names(ini$predictorMatrix), row.names(ini$predictorMatrix)))

## specify the imputation model
#ini$predictorMatrix["mat_age_delivery", 19:32] = 1
#ini$predictorMatrix["male", c(5:8, 19:32)] = 1

ini$predictorMatrix["child_birth_weight.ph1", 21:33] = 1
ini$predictorMatrix["mat4race", c(9, 21:33)] = 1
ini$predictorMatrix["hispanic", c(9:10, 21:33)] = 1
ini$predictorMatrix["mat_diabetes3", c(9:11, 21:33)] = 1
ini$predictorMatrix["cesarean", c(9:12, 21:33)] = 1
ini$predictorMatrix["depressionr", c(9:13, 21:33)] = 1
ini$predictorMatrix["tobacPregr", c(9:14, 21:33)] = 1
ini$predictorMatrix["insurancer", c(9:15, 21:33)] = 1
ini$predictorMatrix["singleton", c(9:16, 21:33)] = 1
ini$predictorMatrix["married", c(9:17, 21:33)] = 1
ini$predictorMatrix["number_children", c(9:18, 21:33)] = 1
ini$predictorMatrix["egaWk", c(9:19, 21:33)] = 1

meth = ini$method
meth[meth!=""] = ""
meth["child_birth_weight.ph1"] = "norm"
meth["mat4race"] = "polyreg"
meth["hispanic"] = "logreg"
meth["mat_diabetes3"] = "polyreg"
meth["cesarean"] = "logreg"
meth["depressionr"] = "logreg"
meth["tobacPregr"] = "logreg"
meth["insurancer"] = "logreg"
meth["singleton"] = "logreg"
meth["married"] = "logreg"
meth[c("number_children")] = "qpois"
meth[c("egaWk")] = "norm"


post <- ini$post
post["egaWk"] <- "imp[[j]][,i] <- squeeze(imp[[j]][,i],c(24,44))"

mip = matrix(FALSE, nrow = nrow(bothPhases2), ncol = ncol(bothPhases2))
mip[,c(9:18, 20)] = TRUE
mip[, 19] = is.na(bothPhases2$number_children)

imp = mice(bothPhases2, meth = meth, pred = ini$predictorMatrix, print = F, m = 100, post = post,
           where = mip, seed = 0111)


id = readRDS("id_obesity.rds")

imp.data = list()
for(i in 1:100){
  ff = complete(imp, i)[1:10335,]
  ff1 = complete(imp, i)[10336:11331,]
  ff[ff$in.phase2 == 1,]$number_children = ff1$number_children
  imp.data[[i]] = ff
}

imp.data.id = list()
for(i in 1:100){
  imp.data.id[[i]] = merge(imp.data[[i]], id, by="baby_studyid")
}



saveRDS(imp.data.id, file = "impdata_obesity.rds")




out.list = list()
for (i in 1:100){
  out.list[[i]] = readRDS(paste0("out", i, ".rds"))
  out.list[[i]]$est_bmi_gest_imp = out.list[[i]]$est_bmi_gest
  out.list[[i]]$estWtChangePerWk_imp = out.list[[i]]$estWtChangePerWk
  out.list[[i]]$est_bmi_gest = NULL
  out.list[[i]]$estWtChangePerWk = NULL
}


impdata_obesity = readRDS("impdata_obesity.rds")
combine.list = list()
for(i in 1:100){
  combine.list[[i]] = merge(impdata_obesity[[i]], out.list[[i]], by="baby_studyid")
}

saveRDS(combine.list, "combine_data_obesity.rds")



################################
##                            ##
##  Step 3: impute ttobesity  ##
##                            ##
################################

combine.list = readRDS("combine_data_obesity.rds")


for(i in 1:100){
  set.seed(100*i)
  ob1 = combine.list[[i]][combine.list[[i]]$obesity.ph1 == 1,]
  fit1 = lm(ttobesity~ ttobesity.ph1 + child_birth_weight.ph1 + mat4race + hispanic + mat_diabetes3 + cesarean + depressionr +
            tobacPregr + insurancer + singleton + married + number_children + egaWk + estWtChangePerWk.ph1 + 
            est_bmi_preg_mother.ph1 + mat_age_delivery.ph1 + mat4race.ph1 + hispanic.ph1 + mat_diabetes3.ph1 + cesarean.ph1 +
            male.ph1 + depressionr.ph1 + tobacPregr.ph1 + insurancer.ph1 + singleton.ph1 + est_bmi_gest_imp + estWtChangePerWk_imp
            , data=ob1)
  es.var.ob1 = sum(fit1$residuals^2)/(nrow(ob1[ob1$in.phase2 == 1,]) - 34) 
  ob1$ttobe1 <- rnorm(nrow(ob1), as.vector(predict(fit1, newdata=ob1, type="response", se.fit=FALSE)), sqrt(es.var.ob1))
  ob1$ttobe1 = ifelse(ob1$ttobe1<2, 2, ifelse(ob1$ttobe1>6, 6, ob1$ttobe1))
  
  ob2 = combine.list[[i]][combine.list[[i]]$obesity.ph1 == 0,]
  fit2 = lm(ttobesity~ ttobesity.ph1 + child_birth_weight.ph1 + mat4race + hispanic + mat_diabetes3 + cesarean + depressionr +
            tobacPregr + insurancer + singleton + married + number_children + egaWk + estWtChangePerWk.ph1 + 
            est_bmi_preg_mother.ph1 + mat_age_delivery.ph1 + mat4race.ph1 + hispanic.ph1 + mat_diabetes3.ph1 + cesarean.ph1 +
            male.ph1 + depressionr.ph1 + tobacPregr.ph1 + insurancer.ph1 + singleton.ph1 + est_bmi_gest_imp + estWtChangePerWk_imp
            , data=ob2)
  es.var.ob2 = sum(fit2$residuals^2)/(nrow(ob2[ob2$in.phase2 == 1,]) - 34) 
  ob2$ttobe1 <- rnorm(nrow(ob2), as.vector(predict(fit2, newdata=ob2, type="response", se.fit=FALSE)), sqrt(es.var.ob2))
  ob2$ttobe1 = ifelse(ob2$ttobe1<2, 2, ifelse(ob2$ttobe1>6, 6, ob2$ttobe1))
  
  combine.list[[i]][combine.list[[i]]$obesity.ph1 == 1,]$ttobesity = ob1$ttobe1
  combine.list[[i]][combine.list[[i]]$obesity.ph1 == 0,]$ttobesity = ob2$ttobe1
}


####################################################################
##                                                                ##   
##  Step 4:fit the outcome model and compute influence functions  ##
##                                                                ##                        
####################################################################
library(survival)

inffun_mi <- matrix(0, nrow = nrow(combine.list[[1]]), ncol = 18)
for (i in 1:100){
  mod = coxph(Surv(ttobesity,as.numeric(obesity.ph1),type='right')~estWtChangePerWk_imp + est_bmi_gest_imp+
                mat_age_delivery.ph1+relevel(as.factor(mat4race),ref="White")+ hispanic + 
                relevel(as.factor(mat_diabetes3),ref="None") +cesarean + male.ph1 +tobacPregr+
                depressionr+insurancer +singleton + married + number_children + 
                egaWk,
              data=combine.list[[i]], robust=TRUE)
  
  inffun_mi<-inffun_mi + resid(mod,type="dfbeta",weighted=FALSE)
}

 

inffun_mi<-inffun_mi/100

inffun_mi_id = cbind(inffun_mi, combine.list[[1]]$bababy_studyid, combine.list[[1]]$mom_studyid)

saveRDS(inffun_mi_id, file = "inffun_obesity.rds")









