
rm(list=ls(all.names=TRUE))

# R packages required
package_names <- c('MASS','fdapace','lubridate')
invisible(lapply(package_names,require,character.only=TRUE))



### data load 
# workspace for FPCA in the phase 1 analysis
load('~/Box Sync/PCORI-EHR-PENN-VUMC/Kyunghee/dataset/preliminary-04272020.RData')
df_mother_phase1 <- df_all_preg
fpca_weight_mother_phase1 <- fpca_weight_mother
Lt_mother_phase1 <- fpca_weight_mother_phase1$inputData$Lt
Ly_mother_phase1 <- fpca_weight_mother_phase1$inputData$Ly
id_mother_phase1 <- as.numeric(names(Lt_mother_phase1))

# RDS file generated by Aihua
pcori_data_audit <- readRDS("~/Box Sync/PCORI-EHR-PENN-VUMC/Aihua/2020-07-16/pennlist2020-07-16.rds")

# mother-child id link
id_child_mother_link <- readRDS('~/Box Sync/PCORI-EHR-PENN-VUMC/Kyunghee/dataset/phase1_id_child_mother_link.rds')

# wave3 child id 
pam_wave3 <- read.csv('/Users/kyungheehan/Box Sync/PCORI-EHR-PENN-VUMC/Pam/wave3ID.csv')
id_child_wave3 <- as.numeric(pam_wave3$id)
length(unique(id_child_wave3))

# associated mother's id in phase 1
id_mother_wave3 <- id_child_mother_link$mom_studyid[which(id_child_mother_link$baby_studyid %in% id_child_wave3)]
length(unique(id_mother_wave3))
sum(id_mother_wave3 %in% id_mother_phase1)



### confidence band
fit_mat_phase1 <- fitted(fpca_weight_mother_phase1)

Lambda_mat_phase1 <- diag(fpca_weight_mother_phase1$lambda)
grid_vec_phase1 <- fpca_weight_mother_phase1$workGrid
phi_mat_phase1 <- fpca_weight_mother_phase1$phi

alpha <- 0.05

ciband_wave3 <- ciout_wave3 <- list()
for (j in 1:length(id_mother_wave3)) {
  i <- id_mother_wave3[j]
  
  ind_Lt <- which(id_mother_phase1==i)
  
  Lt_i <- Lt_mother_phase1[[ind_Lt]]
  Ly_i <- Ly_mother_phase1[[ind_Lt]]
  
  phi_i <- apply(phi_mat_phase1,2,function (y) spline(x=grid_vec_phase1,y=y,xout=Lt_i)$y)
  if (class(phi_i)[1]=='numeric') {
    phi_i <- t(phi_i)
  }
  H_i <- t(phi_i%*%Lambda_mat_phase1)
  G_i <- phi_i%*%Lambda_mat_phase1%*%t(phi_i) + diag(fpca_weight_mother_phase1$sigma2,length(Lt_i))
  
  Omega_i <- Lambda_mat_phase1 - H_i%*%solve(G_i)%*%t(H_i)
  
  y_i <- fit_mat_phase1[ind_Lt,]
  se_i <- sqrt(qchisq(1-alpha,df=ncol(phi_mat_phase1))*diag(phi_mat_phase1%*%Omega_i%*%t(phi_mat_phase1)))
  
  ind_df <- which(df_mother_phase1$studyid==i)
  est_gest_date_i <- df_mother_phase1$imp_gest_date[ind_df][1]
  baby_studyid_i <- df_mother_phase1$baby_studyid[ind_df][1]
  mother_dob_i <- df_mother_phase1$mother_dob[ind_df][1]
  baby_dob_i <- df_mother_phase1$baby_dob[ind_df][1]
  
  ciband_wave3[[j]] <- data.frame(date_grid=grid_vec_phase1+est_gest_date_i,
                                  fitted=y_i,
                                  se=se_i,
                                  lower=y_i-se_i,
                                  upper=y_i+se_i)
  
  y_sub_i <- spline(grid_vec_phase1,y_i,xout=Lt_i)$y
  se_sub_i <- spline(grid_vec_phase1,se_i,xout=Lt_i)$y
  
  ind_out <- ifelse(Ly_i<(y_sub_i-se_sub_i) | Ly_i>(y_sub_i+se_sub_i),1,0)
  ciout_wave3[[j]] <- data.frame(mom_studyid=rep(as.numeric(i),length(Lt_i)),
                                 baby_studyid=rep(baby_studyid_i,length(Lt_i)),
                                 mother_dob=rep(mother_dob_i,length(Lt_i)),
                                 baby_dob=rep(baby_dob_i,length(Lt_i)),
                                 mother_wgt=Ly_i,
                                 measure_date=(Lt_i+est_gest_date_i),
                                 outlier=ind_out)
}
names(ciband_wave3) <- names(ciout_wave3) <- id_mother_wave3

sdf_wave3 <- data.frame(do.call(rbind,ciout_wave3),row.names=NULL)
# saveRDS(sdf_wave3,'/Users/kyungheehan/Box Sync/PCORI-EHR-PENN-VUMC/Kyunghee/dataset/wave3_maternal_weight_outlier_11302020.rds')
# write.csv(sdf_wave3,'/Users/kyungheehan/Box Sync/PCORI-EHR-PENN-VUMC/Kyunghee/dataset/wave3_maternal_weight_outlier_11302020.csv',row.names=FALSE)



## checking outliers
ind_out <- which(unlist(lapply(ciout_wave3,function(L) sum(L$outlier)))>0)
if (length(ind_out)==0) {
  
  print('All measurements fall into confidence bands.')
  id_mother_wave3_out <- id_mother_wave3
  
} else {
  
  id_mother_wave3_out <- as.numeric(names(ind_out))
  print(ind_out)
  length(id_mother_wave3_out)
  
}


for (i in id_mother_wave3_out) {
  
  # png(paste('~/Box Sync/PCORI-EHR-PENN-VUMC/Kyunghee/wave3-re-investigation/wave3-subset-mother-confidence-band-',i,'.png',sep=''),width=8,height=6,units='in',res=100,bg='transparent')

  ind_i <- which(id_mother_wave3==i)

  par(mfrow=c(1,1))
  par(mar=c(4.5,4.5,2,1.5)+0.1,
      cex.axis=1,cex.lab=1.5,cex.main=1.5)
  
  ind_df <- which(df_mother_phase1$studyid==i)
  
  imp_gest_date_i <- df_mother_phase1$imp_gest_date[ind_df][1]
  baby_dob_i <- df_mother_phase1$baby_dob[ind_df][1]
  ega_i <- difftime(baby_dob_i,imp_gest_date_i,units='days')
  
  date1 <- floor_date(min(ciout_wave3[[ind_i]]$measure_date,imp_gest_date_i),'month')
  date2 <- max(ciout_wave3[[ind_i]]$measure_date,baby_dob_i)
  
  plot(ciband_wave3[[ind_i]]$date_grid,ciband_wave3[[ind_i]]$fitted,type='l',lwd=2.5,col=8,
       xlim=c(date1,date2),
       xaxt = 'n',
       ylim=range(c(ciband_wave3[[ind_i]]$lower,
                    ciband_wave3[[ind_i]]$upper,
                    ciout_wave3[[ind_i]]$mother_wgt))*c(0.9,1.15),
       xlab='Date (mm/dd/yy)',ylab='Weight (kg)',
       main=paste('Mother Study ID: ',i,sep=''))
  
  points(ciout_wave3[[ind_i]]$measure_date,ciout_wave3[[ind_i]]$mother_wgt,pch=3,
         cex=ifelse(ciout_wave3[[ind_i]]$outlier==1,1.5,1),
         col=ifelse(ciout_wave3[[ind_i]]$outlier==1,2,1))
  
  lines(ciband_wave3[[ind_i]]$date,ciband_wave3[[ind_i]]$lower,col=1,lty=2,lwd=1.5)
  lines(ciband_wave3[[ind_i]]$date,ciband_wave3[[ind_i]]$upper,col=1,lty=2,lwd=1.5)
  
  axis(1,
       seq(floor_date(date1,'month'),
           ceiling_date(date2,'month'),length.out=8),
       format(seq(floor_date(date1,'month'),
                  ceiling_date(date2,'month'),length.out=8), 
              "%m/%d/%y"))
  
  abline(v=seq(floor_date(date1,'month'),
               ceiling_date(date2,'month'),length.out=8),
         col=8,lty=3)
  abline(h=seq(0,200,10),col=8,lty=3)
  
  abline(v=c(imp_gest_date_i,baby_dob_i),col=c(2,4))
  
  legend('topright',c('95% Conf. Band',
                      'Est. Trajectory'),
         lwd=c(1.5,2.5),cex=1.25,lty=c(2,1),col=c(1,8),bty='n')
  
  legend('bottomright',paste('EGA = ',ega_i,' days',sep=''),
         lty=-1,pch=-1,cex=1.25,bty='n')
  legend('topleft',c(paste('Baby Birth (',format(baby_dob_i,"%m/%d/%y"),')',sep=''),
                     paste('Est. Gestation (',format(imp_gest_date_i,"%m/%d/%y"),')',sep='')),
         lwd=1.5,cex=1.25,lty=1,col=c(4,2),bty='n')
  
  # dev.off()
}

