##### Final PCORI analysis

######
rm(list=ls())

### Read in necessary pacakges
library(survey)
library(survival)


### Necessary home-made functions 

###### 
CIfunc<-function(beta,se){
	cbind(beta,beta - qnorm(.975)*se, beta+qnorm(.975)*se)
}

#### Logistic regression influence function  (changed name, but is Tong's function)
### Tong's binary influence function for binary data
inf.fun.logit <- function(fit) {
  dm <- model.matrix(fit)
  Ihat <- (t(dm) %*% (dm * fit$fitted.values * (1 - fit$fitted.values))) / nrow(dm)
  ## influence function
  infl <- (dm * resid(fit, type = "response")) %*% solve(Ihat)
  infl
}



#### Set working directory here. Do not do this later in file
###Pam's wd
#setwd("~/Box/PCORI-EHR-PENN-VUMC/")
###Bryan's wd
setwd("~/Documents/data-files/pcori-analyses/data-3-may2021/")
path<-"~/Documents/data-files/pcori-analyses/data-3-may2021/"


######################################################################
#### Read in new data with all covariates and reduce back down to original cohort of 10335.
######################################################################
###Phase 1 data from Aihua. Need to rename some variables to be consistent with phase 2 and backwards compatible
phase1<-readRDS(paste0(path,"phase1data_2021-04-29.rds"))
#phase1<-readRDS("Aihua/2021-04-26Riskfactors/phase1data_2021-04-29.rds")
names(phase1)
names(phase1)[names(phase1)=="child_studyid"]<-"baby_studyid"
names(phase1)[names(phase1)=="mom_studyid"]<-"studyid"
names(phase1)[names(phase1)=="child_age_at_obesity"]<-"ttobesity"
#dim(phase1)
#[1] 20684    23

### original phase1 data, included Kyunghee's variables
#phase1.orig<-read.csv("~/Dropbox/PCORI Healthy Weight/Pam/Phase1.csv")
phase1.orig<-read.csv("~/Dropbox/pam/pcori-methods-2016/PCORI Healthy Weight/Pam/Phase1.csv")
names(phase1.orig)
#> dim(phase1.orig)
#[1] 10335    12

#get rid of varibles duplicated in phase1
phase1.orig<-phase1.orig[,c("baby_studyid","est_wgt_change_mother","est_bmi_preg_mother")]
  
### subset dataset to original cohort and merge in Kyunghee's variables
phase1<-merge(phase1.orig,phase1,by="baby_studyid",all.x=T)

####  Now rename/recode all variables so backwards compatible 
phase1$mat4race<-"Other"
phase1$mat4race<-ifelse(phase1$mat_race=="A","Asian",phase1$mat4race)
phase1$mat4race<-ifelse(phase1$mat_race=="B","Black",phase1$mat4race)
phase1$mat4race<-ifelse(phase1$mat_race=="W","White",phase1$mat4race)
phase1$hispanic<-ifelse(phase1$mat_ethnicity =="HL",1,0)
phase1$male<-ifelse(phase1$child_sex=="M",1,0)
phase1$mat_diabetes<-ifelse(phase1$mat_diabetes=="Yes",1,0)
phase1$mat_diabetes3<-with(phase1,ifelse(mat_diabetes==1,"Type 1/2",
                                            ifelse(mat_gest_diabetes=="Yes","Gestational","None")))
phase1$cesarean<-ifelse(is.na(phase1$cesarean),0,phase1$cesarean)
phase1$cesarean<-ifelse(phase1$cesarean=="Yes",1,0)
phase1$mat_smoking<-ifelse(is.na(phase1$mat_smoking),0,phase1$mat_smoking) ### lots of missing, so need to set base level
phase1$tobacPregr<-ifelse(phase1$mat_smoking=="Yes",1,0)
phase1$mat_depression<-ifelse(is.na(phase1$mat_depression),0,phase1$mat_depression)  ### lots of missing
phase1$depressionr<-ifelse(phase1$mat_depression=="Yes",1,0)
phase1$mat_insurance<-ifelse(is.na(phase1$mat_insurance),"Unknown",phase1$mat_insurance)
phase1$insurancer<- ifelse(phase1$mat_insurance=="Private","Private","Public/Other") 
phase1$obesity<-ifelse(phase1$child_obesity=="Yes",1,0)
phase1$estWtChangePerWk<-phase1$est_wgt_change_mother/39 ### avg length of pregnancy from conception (not last menstrual period)
phase1$singleton<-ifelse(phase1$singleton=="Yes",1,0)
phase1$asthma<-ifelse(phase1$child_asthma=="yes",1,0)
phase1$mat_asthma<-ifelse(phase1$mat_asthma=="Yes",1,0)

#### Add ph1 suffix so can merge with phase 2 data of same name. 
for(i in 3:ncol(phase1)) names(phase1)[i]<-paste(names(phase1[i]),"ph1",sep=".")

### Phase 2 data from Aihua
#phase2<-readRDS("Aihua/2021-04-26Riskfactors/phase2data_2021-04-29.rds")
phase2<-readRDS(paste0(path,"phase2data_2021-05-11.rds"))

sort(names(phase2))
#> dim(phase2)
#[1] 996  67

#Create needed variables
phase2$male<-ifelse(phase2$child_sex.factor=="Male",1,0)
phase2$mat_age_delivery<-as.numeric(phase2$baby_dob - phase2$mom_dob)/365.25
phase2$mat4race<-"Other"
phase2$mat4race<-ifelse(phase2$mat_race.factor =="Asian", "Asian",phase2$mat4race)
phase2$mat4race<-ifelse(phase2$mat_race.factor =="Black or African American", "Black",phase2$mat4race)
phase2$mat4race<-ifelse(phase2$mat_race.factor =="White", "White",phase2$mat4race)
phase2$hispanic<-ifelse(phase2$ethnicity.factor =="Hispanic (all)",1,0)
phase2$cesarean<-ifelse(phase2$delivery_type.factor=="Vaginal",0,1)
phase2$tobacPregr<-ifelse(phase2$tobacco_use_preg.factor=="Yes",1,0)
phase2$mat_depression.factor<-ifelse(is.na(phase2$mat_depression.factor),0,phase2$mat_depression.factor)
phase2$depressionr<-ifelse(phase2$mat_depression.factor==1,1,0)
phase2$mat_diabetes<-ifelse(is.na(phase2$mat_diabetes),0,phase2$mat_diabetes)
phase2$gest_diabetes<-with(phase2,ifelse(is.na(diabetes_preg.factor),"Unknown / Not Reported", as.character(diabetes_preg.factor)))
phase2$mat_diabetes3<-with(phase2,ifelse(mat_diabetes==1,"Type 1/2",
                                            ifelse(gest_diabetes=="Yes","Gestational","None")))
phase2$insurancer<-ifelse(phase2$insurance.factor=="Private insurance","Private","Public/Other")
phase2$married<-ifelse(phase2$marital_status.factor=="Married",1,0)
phase2$singleton<-ifelse(is.na(phase2$singleton),0,phase2$singleton)
phase2$asthma<-ifelse(phase2$child_asthma.factor=="Yes",1,0)
phase2$mat_asthma<-ifelse(is.na(phase2$mat_asthma),0,phase2$mat_asthma)

phase2$ttasthma<-as.numeric(phase2$child_asthma_date - phase2$baby_dob+1)/365.25
phase2$obesity<-ifelse(phase2$child_obesity=="Yes",1,0)
phase2$ttobesity<-phase2$child_age_at_obesity


#### Sampling frame variables
phase2$in.phase2<-1 ### in validated sample


phase2$in.Ophase2<-with(phase2, ifelse(obesity_wave1=="Yes"|obesity_wave2=="Yes"|
                                        obesity_wave3=="Yes"|obesity_wave4=="Yes",1,0))
phase2$in.Aphase2<-with(phase2, ifelse(asthma_wave1=="Yes"|asthma_wave2=="Yes",1,0))





##### Have to get Kyunghee's phase 2 variables
#wave12<-read.csv("Pam/wave12.csv")
wave12<-read.csv(paste0(path,"wave12.csv"))
wave12<-wave12[,c("baby_studyid","estWtChangePerWk","est_bmi_gest","egaWk")]

#momV.w3<-readRDS( "Kyunghee/dataset/mother_dataset_validated_wave3-12212020.rds") 
#momV.w4<-readRDS("Kyunghee/dataset/mother_dataset_validated_wave4-01282021.rds") 
#momV.w5<-readRDS("Kyunghee/dataset/mother_dataset_validated_asthma_wave1-03242021.rds")
#momV.w6<-readRDS("Kyunghee/dataset/mother_dataset_validated_asthma_wave2-04292021.rds")
momV.w3<-readRDS(paste0(path,"mother_dataset_validated_wave3-12212020.rds")) 
momV.w4<-readRDS(paste0(path,"mother_dataset_validated_wave4-01282021.rds")) 
momV.w5<-readRDS(paste0(path,"mother_dataset_validated_asthma_wave1-03242021.rds"))
momV.w6<-readRDS(paste0(path,"mother_dataset_validated_asthma_wave2-04292021.rds"))

momV<-rbind(momV.w3,momV.w4,momV.w5,momV.w6)

myMom<-NULL
for(id in unique(momV$studyid)){
	tmp<-momV[momV$studyid==id,]
	myMom<-rbind(myMom,tmp[1,])
}
myMom$matAgeDelivery<-as.numeric(myMom$baby_dob-myMom$mother_dob)/365.25

#### I can confirm ega =estimated ega using this calc.
## My Check
myMom$myega<-myMom$baby_dob - myMom$imp_gest_date

myMom$estWtChangePerWk <-(myMom$est_wt_change/myMom$ega)*7
myMom$egaWk<- (myMom$baby_dob - myMom$imp_gest_date)/7
table(myMom$myega==myMom$ega)
myMom<-myMom[,c("baby_studyid","matAgeDelivery","egaWk","est_bmi_gest","est_wt_change","estWtChangePerWk")]

dim(myMom)


wave3456<-myMom[,c("baby_studyid","estWtChangePerWk","est_bmi_gest","egaWk")]


wave1to6<-merge(wave12,wave3456,all=T)
#> dim(wave1to6)
#[1] 996   3

phase2<-merge(phase2,wave1to6,by="baby_studyid")

### rename for consistency with phase 1
names(phase2)[names(phase2)=="est_bmi_gest"]<-"est_bmi_preg_mother"

### Merge Phase 1 and Phase 2. set sampling frame variables for those not in phase 2 sample
alldata<-merge(phase1,phase2,by="baby_studyid",all.x=T)
alldata$in.Aphase2<-ifelse(is.na(alldata$in.Aphase2),0,alldata$in.Aphase2)
alldata$in.Ophase2<-ifelse(is.na(alldata$in.Ophase2),0,alldata$in.Ophase2)
alldata$in.phase2<-ifelse(is.na(alldata$in.phase2),0,alldata$in.phase2)
# alldata$sampled.Aframe<-ifelse(is.na(alldata$sampled.Aframe),0,alldata$sampled.Aframe)
# alldata$sampled.Oframe<-ifelse(is.na(alldata$sampled.Oframe),0,alldata$sampled.Oframe)
# alldata$in.phase2<-ifelse(is.na(alldata$in.phase2),0,alldata$in.phase2)
table(alldata$in.Aphase2)
table(alldata$in.Ophase2)


dim(alldata)


########Now need to merge in the strata name info.
###############
#### Get wave4 strata variables for obesity frame
###########
#wave4design<-read.csv("Pam/alldataWave4Design.csv")
wave4design<-read.csv(paste0(path,"alldataWave4Design.csv"))
wave4design$in.Oframe<-1
Wave4Strata<-wave4design[,c("id","wave4Strata","in.Oframe")]
names(Wave4Strata)[names(Wave4Strata)=="id"]<-"baby_studyid"
alldata<-merge(alldata,Wave4Strata,by="baby_studyid",all=T)

#### Get wave6 strata variables for asthma 
#wave6design<-read.csv("Tong/asthma_sampling_wave2/wave2design.csv")
wave6design<-read.csv(paste0(path,"wave2design.csv"))
wave6design$in.Aframe<-1
Wave6Strata<-wave6design[,c("id","strata","in.Aframe")]
names(Wave6Strata)[names(Wave6Strata)=="strata"]<-"wave6Strata"
names(Wave6Strata)[names(Wave6Strata)=="id"]<-"baby_studyid"
alldata<-merge(alldata,Wave6Strata,by="baby_studyid",all=T)

alldata$in.Aframe<-ifelse(is.na(alldata$in.Aframe),0,1)

table(alldata$in.Aframe)
table(alldata$in.Oframe)


##### Reading in multiply imputed IF from Tong

Ainfdata<-data.frame(readRDS(paste0(path,"inffun_asthma.rds")))
dim(Ainfdata)
### This code needs to be verified, prefer a merge statement
alldata<-merge(alldata,Ainfdata[,c("baby_studyid","estWtChangePerWk_imp")],by="baby_studyid",all.x=T)
names(alldata)[names(alldata)=="estWtChangePerWk_imp"]<-"MIInfl.asthma"
dim(alldata)

infdata<-data.frame(readRDS(paste0(path,"inffun_obesity.rds")))
dim(infdata)

### verify code
infdata<-infdata[,c("baby_studyid","estWtChangePerWk_imp")]
alldata<-merge(alldata,infdata[,c("baby_studyid","estWtChangePerWk_imp")],by="baby_studyid",all.x=T)
names(alldata)[names(alldata)=="estWtChangePerWk_imp"]<-"MIInfl.obesity"




##  BRYAN: I am going to remove variables from alldata that we do not end up needing/using anymore.
alldata$marital_status.factor<-
alldata$mat_race.factor<-
alldata$ethnicity.factor<-                  
alldata$marital_status.factor<-
alldata$tobacco_use.factor<-                
alldata$tobacco_use_preg.factor<-
alldata$alcohol_use_preg.factor<-
alldata$mat_diabetes.factor<-
alldata$mat_diabetes_d_2.factor<-
alldata$diabetes_preg.factor<-
alldata$mat_depression.factor<-
alldata$mat_asthma.factor<-
alldata$insurance.factor<- 
alldata$delivery_type.factor<-
alldata$singleton.factor<-
alldata$child_sex.factor<-
alldata$feeding.factor<-
alldata$child_asthma.factor<-
alldata$abstractor.factor<-
alldata$motherchild_record_complete.factor<-
alldata$obesity_wave1<-                     
alldata$obesity_wave2<-
alldata$obesity_wave3<-
alldata$obesity_wave4<-
alldata$asthma_wave1<-
alldata$asthma_wave2<-NULL
  
saveRDS(alldata, file = "analysisData20210511-bes.rds")

####################################################
#####  Now I am going to compute summary statistics and compare variables across phase 1 and phase 2 samples

table(alldata$obesity.ph1)
mean(alldata$obesity.ph1)
table(alldata$obesity)
mean(alldata$obesity,na.rm=TRUE)
mean(alldata$obesity[alldata$in.phase2==1])
with(alldata, mean(obesity.ph1[in.phase2==1]!=obesity[in.phase2==1]))
with(alldata, sum((obesity.ph1!=obesity)&in.phase2==1))
with(alldata, mean(obesity[obesity.ph1==1&in.phase2==1]))
with(alldata, 1-mean(obesity[obesity.ph1==0&in.phase2==1]))
with(alldata, table(obesity.ph1,obesity))

summary(alldata$ttobesity.ph1)
summary(alldata$ttobesity)
with(alldata, mean(ttobesity.ph1[in.phase2==1]!=ttobesity[in.phase2==1]))
with(alldata, sum((ttobesity.ph1!=ttobesity)&in.phase2==1))
with(alldata, summary((ttobesity-ttobesity.ph1)[(ttobesity.ph1!=ttobesity)&in.phase2==1]))

summary(alldata$estWtChangePerWk.ph1)
summary(alldata$estWtChangePerWk)
with(alldata, mean(estWtChangePerWk.ph1[in.phase2==1]!=estWtChangePerWk[in.phase2==1]))
with(alldata, summary(estWtChangePerWk[in.phase2==1]-estWtChangePerWk.ph1[in.phase2==1]))
with(alldata, mean(abs(estWtChangePerWk[in.phase2==1]-estWtChangePerWk.ph1[in.phase2==1])<0.1))

summary(alldata$est_bmi_preg_mother.ph1)
summary(alldata$est_bmi_preg_mother)
with(alldata, mean(est_bmi_preg_mother.ph1[in.phase2==1]!=est_bmi_preg_mother[in.phase2==1]))
with(alldata, summary(est_bmi_preg_mother[in.phase2==1]-est_bmi_preg_mother.ph1[in.phase2==1]))
with(alldata, mean(abs(est_bmi_preg_mother[in.phase2==1]-est_bmi_preg_mother.ph1[in.phase2==1])<1))

summary(alldata$mat_age_delivery.ph1)
summary(alldata$mat_age_delivery)
with(alldata, mean(mat_age_delivery[in.phase2==1]!=mat_age_delivery.ph1[in.phase2==1]))
with(alldata, summary(mat_age_delivery[in.phase2==1]-mat_age_delivery.ph1[in.phase2==1]))

round(table(alldata$mat4race.ph1)/sum(table(alldata$mat4race.ph1)),3)
round(table(alldata$mat4race)/sum(table(alldata$mat4race)),3)
with(alldata, mean(mat4race[in.phase2==1]!=mat4race.ph1[in.phase2==1]))
with(alldata, mean(mat4race[mat4race.ph1=="White"&in.phase2==1]=="White"))
with(alldata, mean(mat4race[mat4race.ph1!="White"&in.phase2==1]!="White"))
with(alldata, mean(mat4race[mat4race.ph1=="Black"&in.phase2==1]=="Black"))
with(alldata, mean(mat4race[mat4race.ph1!="Black"&in.phase2==1]!="Black"))
with(alldata, mean(mat4race[mat4race.ph1=="Asian"&in.phase2==1]=="Asian"))
with(alldata, mean(mat4race[mat4race.ph1!="Asian"&in.phase2==1]!="Asian"))
with(alldata, mean(mat4race[mat4race.ph1=="Other"&in.phase2==1]=="Other"))
with(alldata, mean(mat4race[mat4race.ph1!="Other"&in.phase2==1]!="Other"))

mean(alldata$hispanic.ph1)
mean(alldata$hispanic[alldata$in.phase2==1])
with(alldata, mean(hispanic.ph1[in.phase2==1]!=hispanic[in.phase2==1]))
with(alldata, mean(hispanic[hispanic.ph1==1&in.phase2==1]))
with(alldata, 1-mean(hispanic[hispanic.ph1==0&in.phase2==1]))

round(table(alldata$mat_diabetes3.ph1)/sum(table(alldata$mat_diabetes3.ph1)),3)
round(table(alldata$mat_diabetes3)/sum(table(alldata$mat_diabetes3)),3)
with(alldata, mean(mat_diabetes3[in.phase2==1]!=mat_diabetes3.ph1[in.phase2==1]))
with(alldata, mean(mat_diabetes3[mat_diabetes3.ph1=="None"&in.phase2==1]=="None"))
with(alldata, mean(mat_diabetes3[mat_diabetes3.ph1!="None"&in.phase2==1]!="None"))
with(alldata, mean(mat_diabetes3[mat_diabetes3.ph1=="Gestational"&in.phase2==1]=="Gestational"))
with(alldata, mean(mat_diabetes3[mat_diabetes3.ph1!="Gestational"&in.phase2==1]!="Gestational"))
with(alldata, mean(mat_diabetes3[mat_diabetes3.ph1=="Type 1/2"&in.phase2==1]=="Type 1/2"))
with(alldata, mean(mat_diabetes3[mat_diabetes3.ph1!="Type 1/2"&in.phase2==1]!="Type 1/2"))

mean(alldata$cesarean.ph1)
mean(alldata$cesarean[alldata$in.phase2==1])
with(alldata, mean(cesarean.ph1[in.phase2==1]!=cesarean[in.phase2==1]))
with(alldata, mean(cesarean[cesarean.ph1==1&in.phase2==1]))
with(alldata, 1-mean(cesarean[cesarean.ph1==0&in.phase2==1]))

mean(alldata$male.ph1)
mean(alldata$male[alldata$in.phase2==1])
with(alldata, mean(male.ph1[in.phase2==1]!=male[in.phase2==1]))
with(alldata, mean(male[male.ph1==1&in.phase2==1]))
with(alldata, 1-mean(male[male.ph1==0&in.phase2==1]))

mean(alldata$depressionr.ph1)
mean(alldata$depressionr[alldata$in.phase2==1])
with(alldata, mean(depressionr.ph1[in.phase2==1]!=depressionr[in.phase2==1]))
with(alldata, mean(depressionr[depressionr.ph1==1&in.phase2==1]))
with(alldata, 1-mean(depressionr[depressionr.ph1==0&in.phase2==1]))

round(table(alldata$insurancer.ph1)/sum(table(alldata$insurancer.ph1)),3)
round(table(alldata$insurancer)/sum(table(alldata$insurancer)),3)
with(alldata, mean(insurancer[in.phase2==1]!=insurancer.ph1[in.phase2==1]))
with(alldata, mean(insurancer[insurancer.ph1=="Public/Other"&in.phase2==1]=="Public/Other"))
with(alldata, mean(insurancer[insurancer.ph1!="Public/Other"&in.phase2==1]!="Public/Other"))

mean(alldata$singleton.ph1)
mean(alldata$singleton[alldata$in.phase2==1])
with(alldata, mean(singleton.ph1[in.phase2==1]!=singleton[in.phase2==1]))
with(alldata, mean(singleton[singleton.ph1==1&in.phase2==1]))
with(alldata, 1-mean(singleton[singleton.ph1==0&in.phase2==1]))

mean(alldata$tobacPregr.ph1)
mean(alldata$tobacPregr[alldata$in.phase2==1])
with(alldata, mean(tobacPregr.ph1[in.phase2==1]!=tobacPregr[in.phase2==1]))
with(alldata, mean(tobacPregr[tobacPregr.ph1==1&in.phase2==1]))
with(alldata, 1-mean(tobacPregr[tobacPregr.ph1==0&in.phase2==1]))

## Marital status, number of prior live births, and EGA are not in phase 1 data
mean(alldata$married[alldata$in.phase2==1])
summary(alldata$number_children[alldata$in.phase2==1])
summary(alldata$egaWk[alldata$in.phase2==1])

## Mother and child asthma will only be displayed for those who meet eligibility criteria for both studies

table(alldata$asthma.ph1[alldata$in.Aframe==1])
mean(alldata$asthma.ph1[alldata$in.Aframe==1])
table(alldata$asthma[alldata$in.Aframe==1])
mean(alldata$asthma[alldata$in.phase2==1 & alldata$in.Aframe==1])
with(alldata, mean(asthma.ph1[in.phase2==1 & in.Aframe==1]!=asthma[in.phase2==1 & in.Aframe==1]))
with(alldata, mean(asthma[asthma.ph1==1&in.phase2==1&in.Aframe==1]))
with(alldata, 1-mean(asthma[asthma.ph1==0&in.phase2==1&in.Aframe==1]))
with(alldata, table(asthma.ph1[in.Aframe==1],asthma[in.Aframe==1]))

table(alldata$mat_asthma.ph1[alldata$in.Aframe==1])
mean(alldata$mat_asthma.ph1[alldata$in.Aframe==1])
table(alldata$mat_asthma[alldata$in.Aframe==1])
mean(alldata$mat_asthma[alldata$in.phase2==1 & alldata$in.Aframe==1])
with(alldata, mean(mat_asthma.ph1[in.phase2==1 & in.Aframe==1]!=mat_asthma[in.phase2==1 & in.Aframe==1]))
with(alldata, mean(mat_asthma[mat_asthma.ph1==1&in.phase2==1&in.Aframe==1]))
with(alldata, 1-mean(mat_asthma[mat_asthma.ph1==0&in.phase2==1&in.Aframe==1]))
with(alldata, table(mat_asthma.ph1[in.Aframe==1],mat_asthma[in.Aframe==1]))




###########################################################################
###########################################################################
##### Analysis
###########################################################################
###########################################################################

###########################################################################
###Obesity Model #1: Phase 1 data only 
###########################################################################

naive<-coxph(Surv(ttobesity.ph1,obesity.ph1,type='right')~estWtChangePerWk.ph1+est_bmi_preg_mother.ph1+
               mat_age_delivery.ph1+relevel(as.factor(mat4race.ph1),ref="White")+ hispanic.ph1 + 
               relevel(as.factor(mat_diabetes3.ph1),ref="None") +cesarean.ph1 +male.ph1 +
               tobacPregr.ph1+depressionr.ph1+insurancer.ph1 + singleton.ph1,data=alldata, robust=TRUE)
summary(naive)

ans<-cbind(betaN=c(coef(naive),rep(NA,3)),seN=c(SE(naive),rep(NA,3))) ### phase2 models have 3 extra var
HRans<-CIfunc(ans[,1],ans[,2])
ansMat<-ans
HRansMat<-HRans
HRnames<-c("b.Naive","LL","UL")

alldata$naiveInfl<-resid(naive,type="dfbeta",weighted=FALSE)[,1]     ######  Need to specifically write weighted=FALSE


###############  Fitting non-linear model
####  The next several lines of code fit a model with splines 
####  using only the phase 1 data. We also do some data prep so that 
####  we can fit a similar model with splines in the phase 2 data using raking.
library(splines)
knot.locs<-quantile(alldata$estWtChangePerWk.ph1,c(1/3,2/3))
knotstuff<-ns(alldata$estWtChangePerWk.ph1,knots=knot.locs)
alldata$estWtChangePerWk.s1.ph1<-knotstuff[,1]
alldata$estWtChangePerWk.s2.ph1<-knotstuff[,2]
alldata$estWtChangePerWk.s3.ph1<-knotstuff[,3]
naive.splines<-coxph(Surv(ttobesity.ph1,obesity.ph1,type='right')~
               estWtChangePerWk.s1.ph1+estWtChangePerWk.s2.ph1+estWtChangePerWk.s3.ph1+
                 est_bmi_preg_mother.ph1+
               mat_age_delivery.ph1+relevel(as.factor(mat4race.ph1),ref="White")+ hispanic.ph1 + 
               relevel(as.factor(mat_diabetes3.ph1),ref="None") +cesarean.ph1 +male.ph1 +
               tobacPregr.ph1+depressionr.ph1+insurancer.ph1 + singleton.ph1,data=alldata, robust=TRUE)
summary(naive.splines)

###  Extracting what I want from the splines results
summary(alldata$estWtChangePerWk.ph1)
quantile(alldata$estWtChangePerWk.ph1,c(.01,.99))
WtChangePerWk<-c(0:65)/100
n.length<-length(WtChangePerWk)
####  putting knots in the same location for the dummy data
knotstuff3<-ns(WtChangePerWk,knots=knot.locs,Boundary.knots=range(alldata$estWtChangePerWk.ph1))
knotstuff.s1<-knotstuff3[,1]
knotstuff.s2<-knotstuff3[,2]
knotstuff.s3<-knotstuff3[,3]

#####  Getting influence functions from the naive.splines model. This will be used for phase2 analyses.
alldata$naiveInfl1<-resid(naive.splines,type="dfbeta",weighted=FALSE)[,1]     ######  Need to specifically write weighted=FALSE
alldata$naiveInfl2<-resid(naive.splines,type="dfbeta",weighted=FALSE)[,2]
alldata$naiveInfl3<-resid(naive.splines,type="dfbeta",weighted=FALSE)[,3]

####  knots in same location in phase2 data
knotstuff2<-ns(alldata$estWtChangePerWk,knots=knot.locs, Boundary.knots=range(alldata$estWtChangePerWk.ph1))
alldata$estWtChangePerWk.s1<-knotstuff2[,1]
alldata$estWtChangePerWk.s2<-knotstuff2[,2]
alldata$estWtChangePerWk.s3<-knotstuff2[,3]
alldata$splineinter1<-with(alldata,estWtChangePerWk.s1*est_bmi_preg_mother)
alldata$splineinter2<-with(alldata,estWtChangePerWk.s2*est_bmi_preg_mother)
alldata$splineinter3<-with(alldata,estWtChangePerWk.s3*est_bmi_preg_mother)





######### Fitting Accelerated Failure Time Model
####  For the log-normal model, results are different if we start follow-up at 2 years. However, the log-normal
####  model appears to be a better fit if we start follow-up at birth (0 years), so I have left it.
alldata$y.ph1<-alldata$ttobesity.ph1-2
af.naive<-survreg(Surv(ttobesity.ph1,obesity.ph1,type='right')~estWtChangePerWk.ph1+est_bmi_preg_mother.ph1+
               mat_age_delivery.ph1+relevel(as.factor(mat4race.ph1),ref="White")+ hispanic.ph1 + 
               relevel(as.factor(mat_diabetes3.ph1),ref="None") +cesarean.ph1 +male.ph1 +
               tobacPregr.ph1+depressionr.ph1+insurancer.ph1 + singleton.ph1,data=alldata, robust=TRUE,
               dist="lognormal")
summary(af.naive)

alldata$af.naiveInfl<-resid(af.naive,type="dfbeta",weighted=FALSE)[,2] 

with(alldata, plot(af.naiveInfl,naiveInfl))
with(alldata, cor(af.naiveInfl,naiveInfl))




###########################################################################
###Asthma Model #1: Phase 1 data only. To examine if overfitting issue, 
### Will have full model and reduced model
###########################################################################

#*Full model*
#1.  Estimated weight change per week during pregnancy [1df]
#2.  Estimated BMI at conception [1df]
#3.  Mother’s age at delivery [1df]
#4.  Mother’s race (black, white, asian, other) [3 df]
#5.  Mother’s ethnicity (hispanic, not hispanic) [1df]
#6.  Mother’s diabetes (type 1/2, gestational, none) [2df]
#7.  Cesarean [1df]
#8.  Child sex [1df]
#9.  Mother’s smoking during pregnancy [1df]
#11. Insurance status (public vs. other) [1df]
#15. Estimated gestational age [1df]
#16. Maternal asthma [1df]

alldataA<-alldata[alldata$in.Aframe==1,]
naiveA<-glm(asthma.ph1~estWtChangePerWk.ph1+est_bmi_preg_mother.ph1+mat_age_delivery.ph1+
              relevel(as.factor(mat4race.ph1),ref="White")+ hispanic.ph1 + 
              relevel(as.factor(mat_diabetes3.ph1),ref="None")+ mat_asthma.ph1 +cesarean.ph1 +
              male.ph1 +tobacPregr.ph1+insurancer.ph1,family="quasibinomial",data=alldataA)
summary(naiveA)
####  No evidence of non-linearity in this model either (p=0.75)

table(alldata$asthma.ph1)

table(alldata$wave6Strata[alldata$in.Aframe==1])
table(alldata$wave6Strata)
table(alldata$asthma) ### only 109 events

ans<-cbind(betaN=c(coef(naiveA),rep(NA,1)),seN=c(SE(naiveA),rep(NA,1))) ### phase2 models have 3 extra var
HRans<-CIfunc(ans[,1],ans[,2])
ansMat2<-ans
HRansMat2<-HRans
HRnames2<-c("b.Naive","LL","UL")

# First column is intercept. Take 2nd column, which for estWtChangePerWk.ph1 coef.
alldataA$naiveInfl.asthma<-inf.fun.logit(naiveA)[,2]
alldataAmerging<-alldataA[,c("baby_studyid","naiveInfl.asthma")]
alldata<-merge(alldata,alldataAmerging,by="baby_studyid",all.x=TRUE)


###########################################################################
###########################################################################
##### Study design for single frame twophase sampling
###########################################################################
###########################################################################
### IPW designs
designO <- twophase(id=list(~1,~1),strata=list(NULL,~wave4Strata),subset=~in.Ophase2,
                    data=alldata,method="approx")

designA <- twophase(id=list(~1,~1),strata=list(NULL,~wave6Strata),subset=~in.Aphase2,
                    data=alldata[alldata$in.Aframe==1,],method="approx")



###########################################################################
###########################################################################
##### Set up multi-frame data and weights
###########################################################################
###########################################################################
### Weights Oframe ### correct in.Ophase2
for(s in unique(alldata$wave4Strata)){
	Istrat<-alldata$wave4Strata==s
	Ns<-sum(Istrat)
	ns<-sum(Istrat & alldata$in.Ophase2==1)
	alldata$wtO[Istrat]<-Ns/ns
	alldata$NSO<-Ns
}
### Weights Aframe ### correct in.Aphase2
### Note, wave6Strata is only nonMissing for in.Aframe=1. So ns and Ns will be correct for Aframe subset.
for(s in unique(alldata$wave6Strata[!is.na(alldata$wave6Strata)])){
	Istrat<-alldata$wave6Strata==s
	Ns<-sum(Istrat,na.rm=T)
	ns<-sum(Istrat & alldata$in.Aphase2==1,na.rm=T)
	alldata$wtA[Istrat]<-Ns/ns
	alldata$NsA<-Ns
}


Oframe<-alldata[alldata$in.Oframe==1,]
Oframe$MFstrata<-Oframe$wave4Strata

Aframe<-alldata[alldata$in.Aframe==1,]
Aframe$MFstrata<-Aframe$wave6Strata
mfdata<-data.frame(rbind(Oframe,Aframe))

dim(mfdata)
dim(mfdata[mfdata$in.Aframe==1,])

### Multiframe adjustment (Metcalf and Scott SIM 2009, v28; 1512-1523)
mfdata$wt.tilde<-ifelse((mfdata$in.Oframe*(1-mfdata$in.Aframe))==1,mfdata$wtO,0) + 
			ifelse((mfdata$in.Aframe*(1-mfdata$in.Oframe))==1,mfdata$wtA,0) + 
				ifelse((mfdata$in.Oframe*mfdata$in.Aframe)==1,(mfdata$wtA*mfdata$wtO)/(mfdata$wtA+mfdata$wtO),0)

#### error checking HH weights
mfdata$in.Oonly<-ifelse(mfdata$in.Oframe*(1-mfdata$in.Aframe),TRUE,FALSE)
mfdata$in.Aonly<-ifelse(mfdata$in.Aframe*(1-mfdata$in.Oframe),TRUE,FALSE)
mfdata$in.both<-ifelse((mfdata$in.Oframe*mfdata$in.Aframe)==1,TRUE,FALSE)

table(mfdata$wt.tilde[mfdata$in.Oonly]==mfdata$wtO[mfdata$in.Oonly])
table(mfdata$wt.tilde[mfdata$in.Aonly]==mfdata$wtA) ### Nobody in this category

table(round(mfdata$wt.tilde[mfdata$in.both],5)==round((1/(1/mfdata$wtA[mfdata$in.both]+1/mfdata$wtO[mfdata$in.both])),5))


###########################################################################
###########################################################################
### Obesity Weighted phase 2 Analysis
##############################################################
###########################################################################

###Obesity Model #2: Phase 2 data only
### Single frame analysis, Obesity frame, for comparison with multiframe 
IPWO<-svycoxph(Surv(ttobesity,obesity)~estWtChangePerWk+ est_bmi_preg_mother +
                 mat_age_delivery+ relevel(as.factor(mat4race),ref="White")+ hispanic+
                 relevel(as.factor(mat_diabetes3),ref="None")+cesarean + 
                 male+tobacPregr+depressionr+insurancer+ singleton+ 
                 married + number_children + egaWk,design=designO)	
summary(IPWO)

ans<-cbind(betaIPWO=coef(IPWO),seIPWO=SE(IPWO))
HRans<-CIfunc(ans[,1],ans[,2])
ansMat<-cbind(ansMat,ans)
HRansMat<-cbind(HRansMat,HRans)
row.names(ansMat)<-row.names(ans)
row.names(HRansMat)<-row.names(HRans)
HRnames<-c(HRnames,c("b.IPWO","LL","UL"))


###########################################################################
### Single frame analysis, Obesity outcome/Asthma frame, for comparison with multiframe
###########################################################################

IPWA<-svycoxph(Surv(ttobesity,obesity)~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ relevel(as.factor(mat4race),ref="White")+ hispanic+relevel(as.factor(mat_diabetes3),ref="None")+cesarean + male+tobacPregr+depressionr+insurancer+ singleton+ married + number_children + egaWk,design=designA)	
summary(IPWA)



###########################################################################
### Multi frame analysis for obesity. HH weights. Need to add strata
###########################################################################

designMF <- twophase(id=list(~1,~1),weights=list(~1,~wt.tilde),strata=list(NULL,~MFstrata), 
                     data=mfdata,subset=~in.phase2,method="approx")

IPWmulti<-svycoxph(Surv(ttobesity,obesity)~estWtChangePerWk+ est_bmi_preg_mother +
                     mat_age_delivery+ relevel(as.factor(mat4race),ref="White")+ 
                     hispanic+relevel(as.factor(mat_diabetes3),ref="None")+cesarean + male+tobacPregr+
                     depressionr+insurancer+ singleton+ married + number_children + egaWk,design=designMF)	
 summary(IPWmulti)

ans<-cbind(betaIPWM=coef(IPWmulti),seIPWM=SE(IPWmulti))
HRans<-CIfunc(ans[,1],ans[,2])
ansMat<-cbind(ansMat,ans)
HRansMat<-cbind(HRansMat,HRans)
HRnames<-c(HRnames,c("b.IPWM","LL","UL"))




###########################################################################
### Obesity Model #3: Phase 2 data only with naive raking variable
###########################################################################

Ninflcal<-calibrate(designMF,formula=~naiveInfl+MFstrata,phase=2,calfun="raking") 
IPWMR<-svycoxph(Surv(ttobesity,obesity)~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ 
                  relevel(as.factor(mat4race),ref="White")+ hispanic+relevel(as.factor(mat_diabetes3),ref="None") +
                  cesarean + male+tobacPregr+ depressionr+ insurancer+ singleton + married + number_children + 
                  egaWk,design=Ninflcal)	

summary(IPWMR)

ans<-cbind(betaIPWMR=coef(IPWMR),seIPWMR=SE(IPWMR))
HRans<-CIfunc(ans[,1],ans[,2])
ansMat<-cbind(ansMat,ans)
HRansMat<-cbind(HRansMat,HRans)
HRnames<-c(HRnames,c("b.IPWMR","LL","UL"))



###########################################################################
### Obesity Model #4: Raking with MI auxiliary variable
###########################################################################

MIinflcal<-calibrate(designMF,formula=~MIInfl.obesity+MFstrata,phase=2,calfun="raking") 
IPWMMIR<-svycoxph(Surv(ttobesity,obesity)~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ 
                    relevel(as.factor(mat4race),ref="White")+ hispanic+relevel(as.factor(mat_diabetes3),ref="None") +
                    cesarean + male+tobacPregr+ depressionr+ insurancer+ singleton + married + number_children + 
                    egaWk,design=MIinflcal)	

 summary(IPWMMIR)

 ans<-cbind(betaIPWMMIR=coef(IPWMMIR),seIPWMMR=SE(IPWMMIR))
 HRans<-CIfunc(ans[,1],ans[,2])
 ansMat<-cbind(ansMat,ans)
 HRansMat<-cbind(HRansMat,HRans)
 HRnames<-c(HRnames,c("b.IPWMMIR","LL","UL"))





HRansDF<-data.frame(HRansMat)
names(HRansDF)<-HRnames

row.names(ansMat)<-c("WtChangePerWk","BMI Conception","Age Delivery","Asian","Black","Other","Hispanic","Gest Diabetes","Type I/II Diabetes","Cesarean","Male","Smoking","Depression","Public Insurance","Singleton","Married","No. prior Children","EGA (weeks)")
row.names(HRansMat)<-c("WtChangePerWk","BMI Conception","Age Delivery","Asian","Black","Other","Hispanic","Gest Diabetes","Type I/II Diabetes","Cesarean","Male","Smoking","Depression","Public Insurance","Singleton","Married","No. prior Children","EGA (weeks)")
HRansDF<-data.frame(HRansMat)
names(HRansDF)<-HRnames

round(ansMat,3)
round(exp(HRansDF),3)


####  Changing the HR for weight change to be in terms of 250 g/wk difference:
exp(ansMat[1,1]*.25)
round(exp(HRansDF[1,]*.25),3)
HRs<-round(exp(HRansDF),3)
HRs[1,]<-round(exp(HRansDF[1,]*.25),3)  ## per 250 g/wk
HRs[2,]<-round(exp(HRansDF[2,]*5),3)   ## per 5 BMI
HRs[3,]<-round(exp(HRansDF[3,]*10),3)   ## per 10 years

library(xtable)
print(xtable(HRs, type="latex"), 
      file="HRs-obesity.tex")

ansMatnew<-ansMat
ansMatnew[2,]<-ansMat[2,]*5  ## BMI per 5 units
ansMatnew[3,]<-ansMat[3,]*10 ## age per 10 years
print(xtable(round(ansMatnew,2), type="latex", digits=2), 
      file="betas-obesity.tex")


######################################
######## Non-linear model
####  Raking with naive influence function extracted from 
####  non-linear model fit to phase 1 data

Ninflcal<-calibrate(designMF,formula=~naiveInfl1+naiveInfl2+naiveInfl3+MFstrata,phase=2,calfun="raking") 
IPWMR<-svycoxph(Surv(ttobesity,obesity)~estWtChangePerWk.s1 + estWtChangePerWk.s2 + estWtChangePerWk.s3 +  
                  est_bmi_preg_mother +mat_age_delivery+ 
                  relevel(as.factor(mat4race),ref="White")+ hispanic+relevel(as.factor(mat_diabetes3),ref="None") +
                  cesarean + male+tobacPregr+ depressionr+ insurancer+ singleton + married + number_children + 
                  egaWk,design=Ninflcal)	

###  Suggested code from Thomas to test non-linearity (11/4/2021)
###  Linear term plus all but one of the spline bases
IPWMR.1<-svycoxph(Surv(ttobesity,obesity)~estWtChangePerWk + estWtChangePerWk.s1 + estWtChangePerWk.s2 +  
                  est_bmi_preg_mother +mat_age_delivery+ 
                  relevel(as.factor(mat4race),ref="White")+ hispanic+relevel(as.factor(mat_diabetes3),ref="None") +
                  cesarean + male+tobacPregr+ depressionr+ insurancer+ singleton + married + number_children + 
                  egaWk,design=Ninflcal)	
test<-regTermTest(IPWMR.1, ~estWtChangePerWk.s1+estWtChangePerWk.s2,method="LRT")
test   ##p=0.0067; there is a non-linear association

dummydata2<-data.frame(
                      estWtChangePerWk.s1=knotstuff.s1,
                      estWtChangePerWk.s2=knotstuff.s2,
                      estWtChangePerWk.s3=knotstuff.s3,
                      est_bmi_preg_mother=median(alldata$est_bmi_preg_mother.ph1),
                      mat_age_delivery=median(alldata$mat_age_delivery.ph1),
                      mat4race=factor(smode(alldata$mat4race.ph1)$themodes,levels=unique(alldata$mat4race.ph1)),
                      hispanic=round(mean(alldata$hispanic.ph1)),
                      mat_diabetes3=factor(smode(alldata$mat_diabetes3.ph1)$themodes,levels=unique(alldata$mat_diabetes3.ph1)),
                      cesarean=round(mean(alldata$hispanic.ph1)),
                      male=round(mean(alldata$male.ph1)),
                      tobacPregr=round(mean(alldata$tobacPregr.ph1)),
                      depressionr=round(mean(alldata$depressionr.ph1)),
                      insurancer=factor(smode(alldata$insurancer.ph1)$themodes,levels=unique(alldata$insurancer.ph1)),
                      singleton=round(mean(alldata$singleton.ph1)),
                      married=round(mean(alldata$married,na.rm=TRUE)),
                      number_children=median(alldata$number_children,na.rm=TRUE),
                      egaWk=median(alldata$egaWk,na.rm=TRUE),
                      ttobesity=6,
                      obesity=1
                                         )

### Plotting the linear predictor
est.lp<-predict(object=IPWMR, newdata=dummydata2, type="lp", se.fit=TRUE)
lp.est<-est.lp$fit
lp.low<-est.lp$fit-1.96*est.lp$se.fit
lp.up<-est.lp$fit+1.96*est.lp$se.fit


### Hazard ratios and 95% CI for the Supporting Information (Web Table 1)
logHR<-c(lp.est[WtChangePerWk==0]-lp.est[WtChangePerWk==0.2],
         lp.est[WtChangePerWk==0.1]-lp.est[WtChangePerWk==0.2],
         lp.est[WtChangePerWk==0.3]-lp.est[WtChangePerWk==0.2],
         lp.est[WtChangePerWk==0.4]-lp.est[WtChangePerWk==0.2],
         lp.est[WtChangePerWk==0.5]-lp.est[WtChangePerWk==0.2],
         lp.est[WtChangePerWk==0.6]-lp.est[WtChangePerWk==0.2])

s1Diff<-dummydata2$estWtChangePerWk.s1[c(which(WtChangePerWk==0),which(WtChangePerWk==.1),which(WtChangePerWk==.3),
                                         which(WtChangePerWk==.4),which(WtChangePerWk==.5),which(WtChangePerWk==.6))]-
  dummydata2$estWtChangePerWk.s1[which(WtChangePerWk==.2)]
s2Diff<-dummydata2$estWtChangePerWk.s2[c(which(WtChangePerWk==0),which(WtChangePerWk==.1),which(WtChangePerWk==.3),
                                         which(WtChangePerWk==.4),which(WtChangePerWk==.5),which(WtChangePerWk==.6))]-
  dummydata2$estWtChangePerWk.s2[which(WtChangePerWk==.2)]
s3Diff<-dummydata2$estWtChangePerWk.s3[c(which(WtChangePerWk==0),which(WtChangePerWk==.1),which(WtChangePerWk==.3),
                                         which(WtChangePerWk==.4),which(WtChangePerWk==.5),which(WtChangePerWk==.6))]-
  dummydata2$estWtChangePerWk.s3[which(WtChangePerWk==.2)]

var.logHR<-IPWMR$var[1,1]*s1Diff^2 + IPWMR$var[2,2]*s2Diff^2 + IPWMR$var[3,3]*s3Diff^2 +
              2*IPWMR$var[1,2]*s1Diff*s2Diff + 2*IPWMR$var[1,3]*s1Diff*s3Diff + 2*IPWMR$var[2,3]*s2Diff*s3Diff 
HR.est<-exp(logHR)
HR.est.upper<-exp(logHR+1.96*sqrt(var.logHR))
HR.est.lower<-exp(logHR-1.96*sqrt(var.logHR))
cbind(HR.est,HR.est.lower,HR.est.upper)








######  Accelerated failure time model

### Calibrated
Ninflcal.af<-calibrate(designMF,formula=~af.naiveInfl+MFstrata,phase=2,calfun="raking") 
IPWMR.af<-svysurvreg(Surv(ttobesity,obesity)~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ 
                  relevel(as.factor(mat4race),ref="White")+ hispanic+relevel(as.factor(mat_diabetes3),ref="None") +
                  cesarean + male+tobacPregr+ depressionr+ insurancer+ singleton + married + number_children + 
                  egaWk,dist="lognormal",design=Ninflcal)	
summary(IPWMR.af)
1-exp(IPWMR.af$coeff[2]*0.25)
1-exp(CIfunc(IPWMR.af$coeff[2],SE(IPWMR.af)[2])*.25)


### Without calibration; just IPW 

IPW.af<-svysurvreg(Surv(ttobesity,obesity)~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ 
                  relevel(as.factor(mat4race),ref="White")+ hispanic+relevel(as.factor(mat_diabetes3),ref="None") +
                  cesarean + male+tobacPregr+ depressionr+ insurancer+ singleton + married + number_children + 
                  egaWk,dist="lognormal",design=designMF)	
summary(IPW.af)



###########################################################################
###########################################################################
### Asthma Model #2: IPW for phase2
###single frame analysis
##############################################################
###########################################################################

IPWA<-svyglm(asthma~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ 
               relevel(as.factor(mat4race),ref="White")+ hispanic+ 
               relevel(as.factor(mat_diabetes3),ref="None")+mat_asthma+cesarean + male+ 
               tobacPregr+ insurancer+egaWk,family="quasibinomial",design=designA)	
summary(IPWA)


IPWA.small<-svyglm(asthma~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ 
                     relevel(as.factor(mat4race),ref="White")+ hispanic+ 
                     relevel(as.factor(mat_diabetes3),ref="None")+mat_asthma+tobacPregr+ 
                     insurancer+egaWk,family="quasibinomial",design=designA)	
summary(IPWA.small)

ans<-cbind(betaIPWA=coef(IPWA),seIPWA=SE(IPWA))
ORans<-CIfunc(ans[,1],ans[,2])
ansMat2<-cbind(ansMat2,ans)
ORansMat2<-cbind(HRansMat2,ORans)
ORnames2<-c(HRnames2,c("b.IPWA","LL","UL"))



###########################################################################
### Multi frame analysis for asthma. HH Weights
###########################################################################

designMFA <- twophase(id=list(~1,~1),weights=list(~1,~wt.tilde),strata=list(NULL,~MFstrata), 
                      data=mfdata[mfdata$in.Aframe==1,],subset=~in.phase2,method="approx")

IPWmulti<-svyglm(asthma~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ 
                   relevel(as.factor(mat4race),ref="White")+ hispanic+ 
                   relevel(as.factor(mat_diabetes3),ref="None")+mat_asthma+cesarean + 
                   male+tobacPregr+ insurancer+egaWk,family="quasibinomial",design=designMFA)	

ans<-cbind(betaIPWM=coef(IPWmulti),seIPWM=SE(IPWmulti))
ORans<-CIfunc(ans[,1],ans[,2])
ansMat2<-cbind(ansMat2,ans)
ORansMat2<-cbind(ORansMat2,ORans)
ORnames2<-c(ORnames2,c("b.IPWM","LL","UL"))

###########################################################################
### Asthma Model #3: Phase 2 data only with naive raking variable
###########################################################################

Ninflcal<-calibrate(designMFA,formula=~naiveInfl.asthma+MFstrata,phase=2,calfun="raking") 
IPWMR<-svyglm(asthma~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ 
                relevel(as.factor(mat4race),ref="White")+ hispanic+ 
                relevel(as.factor(mat_diabetes3),ref="None")+mat_asthma+cesarean + 
                male+ tobacPregr+ insurancer+egaWk,family="quasibinomial",design=Ninflcal)	

summary(IPWMR)

ans<-cbind(betaIPWMR=coef(IPWMR),seIPWMR=SE(IPWMR))
ORans<-CIfunc(ans[,1],ans[,2])
ansMat2<-cbind(ansMat2,ans)
ORansMat2<-cbind(ORansMat2,ORans)
ORnames2<-c(ORnames2,c("b.IPWMR","LL","UL"))



###########################################################################
### Asthma Model #4: Phase 2 data only with MI raking variable
###########################################################################

 MIinflcal<-calibrate(designMFA,formula=~MIInfl.asthma+MFstrata,phase=2,calfun="raking") 
IPWMMIR<-svyglm(asthma~estWtChangePerWk+ est_bmi_preg_mother +mat_age_delivery+ 
                  relevel(as.factor(mat4race),ref="White")+ hispanic+ 
                  relevel(as.factor(mat_diabetes3),ref="None")+mat_asthma+cesarean + 
                  male+ tobacPregr+ insurancer+egaWk,family="quasibinomial",design=MIinflcal)	

 summary(IPWMMIR)

  ans<-cbind(betaIPWMMIR=coef(IPWMMIR),seIPWMMIR=SE(IPWMMIR))
  ORans<-CIfunc(ans[,1],ans[,2])
  ansMat2<-cbind(ansMat2,ans)
  ORansMat2<-cbind(ORansMat2,ORans)
  ORnames2<-c(ORnames2,c("b.IPWMMIR","LL","UL"))



row.names(ansMat2)<-c("Intercept","WtChangePerWk","BMI Conception","Age Delivery","Asian","Black","Other","Hispanic","Gest Diabetes","Type I/II Diabetes","Maternal Asthma","Cesarean","Male","Smoking","Public Insurance","EGA (weeks)")
row.names(ORansMat2)<-c("Intercept","WtChangePerWk","BMI Conception","Age Delivery","Asian","Black","Other","Hispanic", "Gest Diabetes","Type I/II Diabetes","Maternal Asthma","Cesarean","Male","Smoking","Public Insurance","EGA (weeks)")

ORansDF2<-data.frame(ORansMat2)
names(ORansDF2)<-ORnames2
round(ansMat2,3)
ORs<-round(exp(ORansDF2),3)


####  Changing the HR for weight change to be in terms of 250 g/wk difference:
exp(ansMat2[2,1]*.25)
ORs[2,]<-round(exp(ORansDF2[2,]*.25),3)  ## per 250 g/wk
ORs[3,]<-round(exp(ORansDF2[3,]*5),3)   ## per 5 BMI
ORs[4,]<-round(exp(ORansDF2[4,]*10),3)   ## per 10 years


print(xtable(ORs, type="latex"), 
      file="ORs-asthma.tex")



ansMat2new<-ansMat2
ansMat2new[3,]<-ansMat2[3,]*5  ## BMI per 5 units
ansMat2new[4,]<-ansMat2[4,]*10 ## age per 10 years
print(xtable(round(ansMat2new,2), type="latex", digits=2), 
      file="betas-asthma.tex")








